==> gura-0.6.2-src.tar.gz: gura-0.6.2/guest/README.md <==
guests
======

Source URLs
-----------

<table>

<tr><td>7za920.zip</td><td>http://www.7-zip.org/</td></tr>

<tr><td>bzip2-1.0.6.tar.gz</td><td>http://www.bzip.org/</td></tr>

<tr><td>cairo-1.12.12.tar.xz</td><td>http://www.cairographics.org/</td></tr>

<tr><td>cmake-2.8.6-win32-x86.exe</td><td>http://www.cmake.org/</td></tr>

<tr><td>combination.hpp</td><td>http://photon.poly.edu/~hbr/boost/combinations.html</td></tr>

<tr><td>curl-7.30.0.zip</td><td>http://curl.haxx.se/</td></tr>

<tr><td>curl_737_1.zip</td><td>http://curl.haxx.se/</td></tr>

<tr><td>dSFMT-src-2.2.1.zip</td><td>http://www.math.sci.hiroshima-u.ac.jp/~m-mat/MT/SFMT/index.html</td></tr>

<tr><td>dtl-1.18.tar.gz</td><td>https://code.google.com/p/dtl-cpp/</td></tr>

<tr><td>expat-2.0.1.tar.gz</td><td>http://expat.sourceforge.net/</td></tr>

<tr><td>freeglut-2.8.1.tar.gz</td><td>http://freeglut.sourceforge.net/</td></tr>

<tr><td>freetype-2.4.11.tar.gz</td><td>http://www.freetype.org/</td></tr>

<tr><td>jpegsr8d.zip</td><td>http://www.ijg.org/</td></tr>

<tr><td>llvm-2.9.tgz</td><td>http://llvm.org/</td></tr>

<tr><td>lpng1510.zip</td><td>http://www.libpng.org/</td></tr>

<tr><td>mpir-2.6.0.tar.bz2</td><td>http://www.mpir.org/</td></tr>

<tr><td>mysql-connector-c-noinstall-6.0.2-win32.zip</td><td>http://dev.mysql.com/downloads/</td></tr>

<tr><td>mysql-connector-c-noinstall-6.0.2-win32-vs2005.zip</td><td>http://dev.mysql.com/downloads/</td></tr>

<tr><td>onig-5.9.2.tar.gz</td><td>http://www.geocities.jp/kosako3/oniguruma/index.html</td></tr>

<tr><td>pixman-0.28.2.tar.gz</td><td>http://www.cairographics.org/</td></tr>

<tr><td>postgresql-8.4.4-1-windows-binaries.zip</td><td>http://www.postgresql.org/download/</td></tr>

<tr><td>postgresql-9.1.2-1-windows-binaries.zip</td><td>http://www.postgresql.org/download/</td></tr>

<tr><td>SDL-1.2.15.zip</td><td>http://www.libsdl.org/</td></tr>

<tr><td>sqlite-amalgamation-3071000.zip</td><td>http://www.sqlite.org/index.html</td></tr>

<tr><td>tcl8511-src.zip</td><td>http://www.tcl.tk/</td><tr>

<tr><td>tiff-3.8.2.zip</td><td>http://www.libtiff.org/</td></tr>

<tr><td>tk8511-src.zip</td><td>http://www.tcl.tk/</td></tr>

<tr><td>UnxUpdates.zip</td><td>http://unxutils.sourceforge.net/</td></tr>

<tr><td>wix38-binaries.zip</td><td>http://wixtoolset.org/</td></tr>

<tr><td>wxWidgets-3.0.1.7z</td><td>http://www.wxwidgets.org/</td></tr>

<tr><td>yaml-0.1.4.tar.gz</td><td>http://pyyaml.org/wiki/LibYAML</td></tr>

<tr><td>zlib127.zip</td><td>http://zlib.net/</td></tr>

</table>

==> gura-0.7.0-src.tar.gz: gura-0.7.0/guest/README.md <==
guests
======

Source URLs
-----------

<table>

<tr><td>7za920.zip</td><td>http://www.7-zip.org/</td></tr>

<tr><td>bzip2-1.0.6.tar.gz</td><td>http://www.bzip.org/</td></tr>

<tr><td>cairo-1.12.12.tar.xz</td><td>http://www.cairographics.org/</td></tr>

<tr><td>cmake-2.8.6-win32-x86.exe</td><td>http://www.cmake.org/</td></tr>

<tr><td>combination.hpp</td><td>http://photon.poly.edu/~hbr/boost/combinations.html</td></tr>

<tr><td>curl-7.30.0.zip</td><td>http://curl.haxx.se/</td></tr>

<tr><td>curl_737_1.zip</td><td>http://curl.haxx.se/</td></tr>

<tr><td>dSFMT-src-2.2.1.zip</td><td>http://www.math.sci.hiroshima-u.ac.jp/~m-mat/MT/SFMT/index.html</td></tr>

<tr><td>dtl-1.18.tar.gz</td><td>https://code.google.com/p/dtl-cpp/</td></tr>

<tr><td>expat-2.0.1.tar.gz</td><td>http://expat.sourceforge.net/</td></tr>

<tr><td>freeglut-2.8.1.tar.gz</td><td>http://freeglut.sourceforge.net/</td></tr>

<tr><td>freetype-2.4.11.tar.gz</td><td>http://www.freetype.org/</td></tr>

<tr><td>jpegsr8d.zip</td><td>http://www.ijg.org/</td></tr>

<tr><td>llvm-2.9.tgz</td><td>http://llvm.org/</td></tr>

<tr><td>lpng1510.zip</td><td>http://www.libpng.org/</td></tr>

<tr><td>liblinear-2.11.zip</td><td>https://www.csie.ntu.edu.tw/~cjlin/liblinear/</td></tr>

<tr><td>libsvm-3.22.zip</td><td>https://www.csie.ntu.edu.tw/~cjlin/libsvm/</td></tr>

<tr><td>mpir-2.6.0.tar.bz2</td><td>http://www.mpir.org/</td></tr>

<tr><td>mysql-connector-c-noinstall-6.0.2-win32.zip</td><td>http://dev.mysql.com/downloads/</td></tr>

<tr><td>mysql-connector-c-noinstall-6.0.2-win32-vs2005.zip</td><td>http://dev.mysql.com/downloads/</td></tr>

<tr><td>onig-5.9.2.tar.gz</td><td>http://www.geocities.jp/kosako3/oniguruma/index.html</td></tr>

<tr><td>pixman-0.28.2.tar.gz</td><td>http://www.cairographics.org/</td></tr>

<tr><td>postgresql-8.4.4-1-windows-binaries.zip</td><td>http://www.postgresql.org/download/</td></tr>

<tr><td>postgresql-9.1.2-1-windows-binaries.zip</td><td>http://www.postgresql.org/download/</td></tr>

<tr><td>SDL-1.2.15.zip</td><td>http://www.libsdl.org/</td></tr>

<tr><td>sqlite-amalgamation-3071000.zip</td><td>http://www.sqlite.org/index.html</td></tr>

<tr><td>tcl8511-src.zip</td><td>http://www.tcl.tk/</td><tr>

<tr><td>tiff-3.8.2.zip</td><td>http://www.libtiff.org/</td></tr>

<tr><td>tk8511-src.zip</td><td>http://www.tcl.tk/</td></tr>

<tr><td>UnxUpdates.zip</td><td>http://unxutils.sourceforge.net/</td></tr>

<tr><td>wix38-binaries.zip</td><td>http://wixtoolset.org/</td></tr>

<tr><td>wxWidgets-3.0.1.7z</td><td>http://www.wxwidgets.org/</td></tr>

<tr><td>yaml-0.1.4.tar.gz</td><td>http://pyyaml.org/wiki/LibYAML</td></tr>

<tr><td>zlib127.zip</td><td>http://zlib.net/</td></tr>

</table>
